@@ -3,7 +3,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2015-2019 Rapptz
+Copyright (c) 2015-2020 Rapptz
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -34,12 +34,14 @@ __all__ = (
     'PrivateMessageOnly',
     'NoPrivateMessage',
     'CheckFailure',
+    'CheckAnyFailure',
     'CommandNotFound',
     'DisabledCommand',
     'CommandInvokeError',
     'TooManyArguments',
     'UserInputError',
     'CommandOnCooldown',
+    'MaxConcurrencyReached',
     'NotOwner',
     'MissingRole',
     'BotMissingRole',
@@ -153,6 +155,26 @@ class CheckFailure(CommandError):
     """
     pass
 
+class CheckAnyFailure(CheckFailure):
+    """Exception raised when all predicates in :func:`check_any` fail.
+
+    This inherits from :exc:`CheckFailure`.
+
+    .. versionadded:: 1.3
+
+    Attributes
+    ------------
+    errors: List[:class:`CheckFailure`]
+        A list of errors that were caught during execution.
+    checks: List[Callable[[:class:`Context`], :class:`bool`]]
+        A list of check predicates that failed.
+    """
+
+    def __init__(self, checks, errors):
+        self.checks = checks
+        self.errors = errors
+        super().__init__('You do not have permission to run this command.')
+
 class PrivateMessageOnly(CheckFailure):
     """Exception raised when an operation does not work outside of private
     message contexts.
@@ -219,12 +241,34 @@ class CommandOnCooldown(CommandError):
         self.retry_after = retry_after
         super().__init__('You are on cooldown. Try again in {:.2f}s'.format(retry_after))
 
+class MaxConcurrencyReached(CommandError):
+    """Exception raised when the command being invoked has reached its maximum concurrency.
+
+    This inherits from :exc:`CommandError`.
+
+    Attributes
+    ------------
+    number: :class:`int`
+        The maximum number of concurrent invokers allowed.
+    per: :class:`BucketType`
+        The bucket type passed to the :func:`.max_concurrency` decorator.
+    """
+
+    def __init__(self, number, per):
+        self.number = number
+        self.per = per
+        name = per.name
+        suffix = 'per %s' % name if per.name != 'default' else 'globally'
+        plural = '%s times %s' if number > 1 else '%s time %s'
+        fmt = plural % (number, suffix)
+        super().__init__('Too many people using this command. It can only be used {} concurrently.'.format(fmt))
+
 class MissingRole(CheckFailure):
     """Exception raised when the command invoker lacks a role to run a command.
 
     This inherits from :exc:`CheckFailure`
 
-    .. versionadded:: 1.1.0
+    .. versionadded:: 1.1
 
     Attributes
     -----------
@@ -242,7 +286,7 @@ class BotMissingRole(CheckFailure):
 
     This inherits from :exc:`CheckFailure`
 
-    .. versionadded:: 1.1.0
+    .. versionadded:: 1.1
 
     Attributes
     -----------
@@ -261,7 +305,7 @@ class MissingAnyRole(CheckFailure):
 
     This inherits from :exc:`CheckFailure`
 
-    .. versionadded:: 1.1.0
+    .. versionadded:: 1.1
 
     Attributes
     -----------
@@ -289,7 +333,7 @@ class BotMissingAnyRole(CheckFailure):
 
     This inherits from :exc:`CheckFailure`
 
-    .. versionadded:: 1.1.0
+    .. versionadded:: 1.1
 
     Attributes
     -----------
@@ -316,7 +360,7 @@ class NSFWChannelRequired(CheckFailure):
 
     This inherits from :exc:`CheckFailure`.
 
-    .. versionadded:: 1.1.0
+    .. versionadded:: 1.1
 
     Parameters
     -----------
@@ -503,7 +547,7 @@ class NoEntryPointError(ExtensionError):
         super().__init__("Extension {!r} has no 'setup' function.".format(name), name=name)
 
 class ExtensionFailed(ExtensionError):
-    """An exception raised when an extension failed to load during execution of the ``setup`` entry point.
+    """An exception raised when an extension failed to load during execution of the module or ``setup`` entry point.
 
     This inherits from :exc:`ExtensionError`
 
@@ -521,19 +565,21 @@ class ExtensionFailed(ExtensionError):
         super().__init__(fmt.format(name, original), name=name)
 
 class ExtensionNotFound(ExtensionError):
-    """An exception raised when an extension failed to be imported.
+    """An exception raised when an extension is not found.
 
     This inherits from :exc:`ExtensionError`
 
+    .. versionchanged:: 1.3
+        Made the ``original`` attribute always None.
+
     Attributes
     -----------
     name: :class:`str`
         The extension that had the error.
-    original: :exc:`ImportError`
-        The original exception that was raised. You can also get this via
-        the ``__cause__`` attribute.
+    original: :class:`NoneType`
+        Always ``None`` for backwards compatibility.
     """
-    def __init__(self, name, original):
-        self.original = original
+    def __init__(self, name, original=None):
+        self.original = None
         fmt = 'Extension {0!r} could not be loaded.'
         super().__init__(fmt.format(name), name=name)
